@@ -3,11 +3,11 @@ from mindee.fields import Field
 
 class Orientation(Field):
     def __init__(
-            self,
-            orientation_prediction,
-            value_key="degrees",
-            reconstructed=False,
-            page_n=None
+        self,
+        orientation_prediction,
+        value_key="degrees",
+        reconstructed=False,
+        page_n=None,
     ):
         """
         :param orientation_prediction: Orientation prediction object from HTTP response
@@ -19,7 +19,7 @@ class Orientation(Field):
             orientation_prediction,
             value_key=value_key,
             reconstructed=reconstructed,
-            page_n=page_n
+            page_n=page_n,
         )
 
         try:
@@ -28,4 +28,4 @@ class Orientation(Field):
                 self.value = 0
         except:
             self.value = 0
-            self.probability = 0.
+            self.probability = 0.0
