@@ -7,7 +7,7 @@ def test_constructor():
         "iban": "iban",
         "routing_number": "routing_number",
         "swift": "swift",
-        "probability": 0.1,
+        "confidence": 0.1,
         "segmentation": {
             "bounding_box": [
                 [0.016, 0.707],
@@ -31,7 +31,7 @@ def test_constructor_all_na():
         "iban": "N/A",
         "routing_number": "N/A",
         "swift": "N/A",
-        "probability": 0.1,
+        "confidence": 0.1,
         "segmentation": {
             "bounding_box": [
                 [0.016, 0.707],
@@ -54,7 +54,7 @@ def test_constructor_all_none():
         "iban": {},
         "routing_number": {},
         "swift": {},
-        "probability": 0.1,
+        "confidence": 0.1,
         "segmentation": {
             "bounding_box": [
                 [0.016, 0.707],
